@@ -4,6 +4,7 @@
 
 do '../web-lib.pl';
 &init_config();
+require '../ui-lib.pl';
 
 # Get the samba version
 if (open(VERSION, "$module_config_directory/version")) {
@@ -534,7 +535,7 @@ if ($has_pdbedit) {
 		"$config{'pdbedit'} -a -s $config{'smb_conf'} -u ".
 		quotemeta($_[0]->{'name'}).
 		" -c '[".join("", @opts)."]' $ws");
-	$? && &error("<pre>$out</pre>");
+	$? && &error("$config{'pdbedit'} failed : <pre>$out</pre>");
 	}
 else {
 	# Add direct to Samba password file
@@ -558,7 +559,7 @@ if ($has_pdbedit) {
 		"$config{'pdbedit'} -r -s $config{'smb_conf'} -u ".
 		quotemeta($_[0]->{'name'}).
 		" -c '[".join("", @opts)."]' 2>&1");
-	$? && &error("<pre>$out</pre>");
+	$? && &error("$config{'pdbedit'} failed : <pre>$out</pre>");
 	}
 else {
 	# Directly update the Samba password file
@@ -575,7 +576,7 @@ if ($has_pdbedit) {
 	local $out = &backquote_logged(
 		"$config{'pdbedit'} -x -s $config{'smb_conf'} -u ".
 		quotemeta($_[0]->{'name'}));
-	$? && &error("<pre>$out</pre>");
+	$? && &error("$config{'pdbedit'} failed : <pre>$out</pre>");
 	}
 else {
 	# Just remove from the Samba password file
@@ -748,11 +749,12 @@ sub delete_group
 local $out;
 if ($has_smbgroupedit) {
 	$out = &backquote_logged("$config{'smbgroupedit'} -x ".quotemeta($_[0]->{'name'})." 2>&1");
+	$? && &error("$config{'smbgroupedit'} failed : <pre>$out</pre>");
 	}
 else {
 	$out = &backquote_logged("$config{'net'} -s $config{'smb_conf'} groupmap delete ntgroup=".quotemeta($_[0]->{'name'})." 2>&1");
+	$? && &error("$config{'net'} failed : <pre>$out</pre>");
 	}
-$? && &error("<pre>$out</pre>");
 }
 
 # modify_group(&group)
@@ -768,6 +770,7 @@ if ($has_smbgroupedit) {
 		($_[0]->{'desc'} ? " -d ".quotemeta($_[0]->{'desc'}) :" -d ''").
 		" -t ".$_[0]->{'type'}.
 		" 2>&1");
+	$? && &error("$config{'smbgroupedit'} failed : <pre>$out</pre>");
 	}
 else {
 	$out = &backquote_logged(
@@ -778,8 +781,8 @@ else {
 		($_[0]->{'desc'} ? " comment=".quotemeta($_[0]->{'desc'})
 				 : " 'comment= '").
 		" type=".quotemeta($_[0]->{'type'})." 2>&1");
+	$? && &error("$config{'net'} failed : <pre>$out</pre>");
 	}
-$? && &error("<pre>$out</pre>");
 }
 
 # create_group(&group)
@@ -795,10 +798,12 @@ if ($has_smbgroupedit) {
 		($_[0]->{'priv'} ? " -p ".quotemeta($_[0]->{'priv'}) : "").
 		($_[0]->{'desc'} ? " -d ".quotemeta($_[0]->{'desc'}) :" -d ''").
 		" -t ".$_[0]->{'type'}." 2>&1");
+	$? && &error("$config{'smbgroupedit'} failed : <pre>$out</pre>");
 	}
 else {
-	$out = &backquote_logged("$config{'net'} -s $config{'smb_conf'} maxrid");
-	$out =~ /rid:\s+(\d+)/ || &error("<pre>$out</pre>");
+	$out = &backquote_logged("$config{'net'} -s $config{'smb_conf'} maxrid 2>&1");
+	$out =~ /rid:\s+(\d+)/ ||
+		&error("$config{'net'} failed : <pre>$out</pre>");
 	local $maxrid = $1 + 1;
 	$out = &backquote_logged(
 		"$config{'net'} -s $config{'smb_conf'} groupmap add".
@@ -812,8 +817,8 @@ else {
 		" ntgroup=".quotemeta($_[0]->{'name'}).
 		($_[0]->{'desc'} ? " comment=".quotemeta($_[0]->{'desc'})
 				 : " 'comment= '")." 2>&1");
+	$? && &error("$config{'net'} failed : <pre>$out</pre>");
 	}
-$? && &error("<pre>$out</pre>");
 }
 
 # get_samba_version(&out)
